import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import { s } from 'node_modules/vite/dist/node/types.d-aGj9QkWt';
// 引入开关组件
type CheckedType = boolean | string | number;
/**
 * transform mock data
 * {
 *  0: '华东分部',
 * '0-0': '华东分部-研发部'
 * '0-1': '华东分部-市场部',
 *  ...
 * }
 */
export const deptMap = (() => {
  const pDept = ['华东分部', '华南分部', '西北分部'];
  const cDept = ['研发部', '市场部', '商务部', '财务部'];

  return pDept.reduce((map, p, pIdx) => {
    map[pIdx] = p;

    cDept.forEach((c, cIndex) => (map[`${pIdx}-${cIndex}`] = `${p}-${c}`));

    return map;
  }, {});
})();

export const columns: BasicColumn[any] = [
  {
    title: '质量规则',
    dataIndex: 'qualityRule',
    width: 120,
  },
  {
    title: '数据源',
    dataIndex: 'dataSource',
    width: 120,
    sorter: true,
  },
  {
    title: '目录',
    dataIndex: 'catalog',
    width: 120,
    sorter: true,
  },
  {
    title: '数据库',
    dataIndex: 'database',
    width: 120,
    sorter: true,
  },
  {
    title: '数据表',
    dataIndex: 'dataTable',
    width: 120,
    sorter: true,
  },
  {
    title: '字段',
    dataIndex: 'fields',
    width: 120,
    sorter: true,
  },
  {
    title: '质量模板',
    dataIndex: 'qualityTemplate',
    width: 150,
  },
  {
    title: '规则组',
    dataIndex: 'ruleGroup',
    width: 150,
  },
  {
    title: '质量通过率',
    dataIndex: 'qualityPassRate',
    width: 120,
    edit: true,
    editable: true,
    editComponentProps: {
      suffix: '%',
    },
  },
];
export const columns2: BasicColumn[any] = [
  {
    title: '路径',
    dataIndex: 'path',
    width: 120,
  },
  {
    title: '文件名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '文件类型',
    dataIndex: 'fileType',
    width: 120,
  },
  {
    title: '目录权属模式',
    dataIndex: 'menuModal',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },
];

export const formSchemaRemove: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
];
export const formSchemaMain: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    // rules: [
    //   {
    //     message: '请选择上级菜单',
    //   },
    // ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名称',
    },
  },
  // {
  //   field: 'des',
  //   label: '描述',
  //   component: 'Input',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     placeholder: '输入描述',
  //   },
  // },
  {
    field: 'fileType',
    label: '文件类型',
    component: 'Input',
    defaultValue: '质量任务',
    colProps: { span: 8 },
    componentProps: {
      readOnly: true,
      disabled: true,
      placeholder: '输入描述',
    },
  },
  {
    field: 'menuModal',
    label: '目录权属模式',
    component: 'Input',
    defaultValue: '本级定义',
    colProps: { span: 8 },
    componentProps: {
      readOnly: true,
      disabled: true,
      placeholder: '输入描述',
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    defaultValue: '默认工作组',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入描述',
      options: [{ label: '默认工作组', value: '默认工作组' }],
      disabled: true,
    },
  },
];
export const formSchema: any = [
  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
];
export const searchFormSchemaForModal: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索规则',
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'testMode',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '检查方式',
      options: [
        { label: '全量', value: '1' },
        { label: '增量', value: '2' },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'ruleGroup',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '规则组',
      options: [
        { label: 'admin_个人工作区', value: '1' },
        { label: '共享工作区', value: '2' },
        { label: '商城工作区', value: '3' },
        { label: '指标工作区', value: '4' },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'releaseStatus',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '发布状态',
      options: [
        { label: '已上线', value: '1' },
        { label: '未上线', value: '2' },
      ],
    },
    colProps: { span: 3 },
  },
  {
    field: 'dateRange',
    label: ' ',
    component: 'RangePicker',
    componentProps: {
      format: 'YYYY-MM-DD', // 显示的日期格式
      valueFormat: 'YYYY-MM-DD', // 提交的日期格式
      placeholder: ['开始时间', '结束时间'], // 占位符
      style: { width: '100%' }, // 控制宽度
    },
    colProps: { span: 5 },
  },
  {
    field: 'businessLabel',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '业务标签',
      options: [
        { label: '生产', value: '1' },
        { label: '质量', value: '2' },
        { label: '人力', value: '3' },
      ],
    },
    colProps: { span: 3 },
  },
  // {
  //   field: 'flag',
  //   label: ' ',
  //   component: 'Select',
  //   componentProps: {
  //     placeholder: '按来源过滤',
  //     options: [{ label: '指标汇总表', value: '1' }],
  //   },
  //   colProps: { span: 8 },
  // },
];
export const resetPasswordFormSchema: any[] = [
  {
    field: 'newPassword',
    label: '新密码',
    component: 'InputPassword',
    componentProps: {
      placeholder: '请输入8~16位，由字母和数字混合所组成的新密码',
    },
    required: true,
    // ifShow: false,
  },
];
const passwordCheck = (rule, value, callback) => {
  const pattern = /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{8,16}$/;
  if (!pattern.test(value)) {
    callback(new Error('新密码必须为数字与字母的组合'));
  }
  callback();
};
export const accountFormSchema: any[] = [
  {
    field: 'username',
    label: '登录名',
    component: 'Input',
    // helpMessage: ['本字段演示异步验证', '不能输入带有admin的用户名'],
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    rules: [
      {
        required: true,
        message: '请输入用户密码',
      },
      { min: 8, max: 16, message: '长度在 8 到 16 个字符', trigger: 'blur' },
      {
        validator: passwordCheck,
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
  },
  {
    field: 'nickName',
    label: '昵称',
    component: 'Input',
  },
  {
    field: 'sex',
    label: '性别',
    component: 'Select',
    componentProps: {
      options: [
        { label: '男', value: '1' },
        { label: '女', value: '0' },
      ],
    },
  },
  {
    field: 'phone',
    label: '手机号码',
    component: 'Input',
    rules: [
      { required: false, message: '请输入手机号码', trigger: 'blur' },
      {
        pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
        message: '请输入正确的手机号码',
        trigger: 'blur',
      },
    ],
  },
  {
    field: 'idNumber',
    label: '身份证号',
    component: 'Input',
    rules: [
      {
        required: false,
        message: '请输入身份证号',
        trigger: 'blur',
      },
      { min: 18, max: 18, message: '长度18字符', trigger: 'blur' },
    ],
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    rules: [
      { required: false, message: '请输入邮箱地址', trigger: 'blur' },
      {
        type: 'email',
        message: '请输入正确的邮箱地址',
        trigger: ['blur', 'change'],
      },
    ],
  },
  {
    field: 'flag',
    label: '状态',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '启用', value: '1' },
        { label: '停用', value: '0' },
      ],
    },
    required: true,
  },
  {
    field: 'deptId',
    label: '所属部门',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'roleList',
    label: '角色',
    component: 'ApiSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // placeholder: '公开给',
      mode: 'multiple',
      api: getAllRoleList,
      labelField: 'roleName',
      valueField: 'businessId',
      resultField: 'data',
    },
    required: true,
  },

  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
  },
];
